package com.mosty.base.manager.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.mosty.base.manager.mapper.TbJcglXfCyryMapper;
import com.mosty.base.manager.mapper.TbJcglXfMapper;
import com.mosty.base.manager.remote.TbBaseAdaptRemoteService;
import com.mosty.base.manager.service.TbJcglXfCyryService;
import com.mosty.base.manager.service.TbJcglXfService;
import com.mosty.base.model.entity.jcgl.TbJcglXf;
import com.mosty.base.model.entity.jcgl.TbJcglXfCyry;
import com.mosty.base.model.query.jcgl.TbJcglXfCyryQuery;
import com.mosty.base.model.query.jcgl.TbJcglXfQuery;
import com.mosty.base.model.vo.base.DeptInfoVo;
import com.mosty.base.utils.IDCardUtil;
import com.mosty.base.utils.UUIDGenerator;
import com.mosty.common.base.exception.BusinessException;
import com.mosty.common.config.Excel.DictUtils;
import com.mosty.common.config.entity.SysDictItem;
import com.mosty.common.token.UserInfo;
import com.mosty.common.token.UserInfoManager;
import lombok.AllArgsConstructor;
import org.apache.commons.lang3.ObjectUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.List;

@AllArgsConstructor
@Service
public class TbJcglXfCyryServiceImpl extends ServiceImpl<TbJcglXfCyryMapper, TbJcglXfCyry>
        implements TbJcglXfCyryService {

    private final TbBaseAdaptRemoteService tbBaseAdaptRemoteService;

    @Override
    public TbJcglXfCyry queryById(String id) {
        return this.baseMapper.selectById(id);
    }

    @Override
    public IPage<TbJcglXfCyry> paginQuery(TbJcglXfCyryQuery query) {
        query.setSsbmdm(this.tbBaseAdaptRemoteService.getSsbm(query.getSsbmdm(), null));
        Page<TbJcglXfCyry> tbJcglXfPage = this.baseMapper.selectPage(new Page<>(query.getPageCurrent(), query.getPageSize()), new LambdaQueryWrapper<TbJcglXfCyry>()
                .likeRight(StringUtils.isNotBlank(query.getSsbmdm()), TbJcglXfCyry::getSsbmdm, query.getSsbmdm())
                .like(StringUtils.isNotBlank(query.getXm()), TbJcglXfCyry::getXm, query.getXm())
                .eq(StringUtils.isNotBlank(query.getSfzh()), TbJcglXfCyry::getSfzh, query.getSfzh())
                .eq(StringUtils.isNotBlank(query.getJg()), TbJcglXfCyry::getJg, query.getJg())
        );
        return tbJcglXfPage;
    }

    @Override
    public Integer insert(TbJcglXfCyry xf) {
        if (StringUtils.isEmpty(xf.getSfzh())) {
            throw new BusinessException("身份证不能为空");
        }
        if (StringUtils.isEmpty(xf.getSsbmdm())) {
            UserInfo userInfo = UserInfoManager.get();
            xf.setSsbmdm(userInfo.getDeptCode());
        }
        //计算籍贯
        String item = DictUtils.getDictLabelByTypeAndValue(xf.getSfzh().substring(0, 6), "D_BZ_XZQHDM", null);
        xf.setJg(item);
        //计算出生日期
        xf.setCsrq(IDCardUtil.getBirthday(xf.getSfzh()));
        //性别
        int gender = Integer.parseInt(xf.getSfzh().substring(16, 17));
        if (gender % 2 == 1) {
            xf.setXb("1");
        } else {
            xf.setXb("2");
        }
        DeptInfoVo dept = this.tbBaseAdaptRemoteService.getOrgByOrgcode(xf.getSsbmdm());
        if (ObjectUtils.isNotEmpty(dept)) {
            xf.setSsbm(dept.getDeptname());
            xf.setSsbmid(dept.getDeptid());
            xf.setSsbmdm(dept.getDeptcode());
            xf.setSsxgajdm(dept.getFxjcode());
            xf.setSsxgajid(dept.getFxjid());
            xf.setSsxgaj(dept.getFxjname());
            xf.setSssgaj(dept.getDszname());
            xf.setSssgajdm(dept.getDszcode());
            xf.setSssgajid(dept.getDszid());
        }
        xf.setId(UUIDGenerator.getUUID());
        return this.baseMapper.insert(xf);
    }

    @Override
    public Integer update(TbJcglXfCyry xf) {
        if (StringUtils.isEmpty(xf.getSfzh())) {
            throw new BusinessException("身份证不能为空");
        }
        if (StringUtils.isEmpty(xf.getSsbmdm())) {
            UserInfo userInfo = UserInfoManager.get();
            xf.setSsbmdm(userInfo.getDeptCode());
        }

        //计算籍贯
        String item = DictUtils.getDictLabelByTypeAndValue(xf.getSfzh().substring(0, 6), "D_BZ_XZQHDM", null);
        xf.setJg(item);
        //计算出生日期
        xf.setCsrq(IDCardUtil.getBirthday(xf.getSfzh()));
        //性别
        int gender = Integer.parseInt(xf.getSfzh().substring(16, 17));
        if (gender % 2 == 1) {
            xf.setXb("1");
        } else {
            xf.setXb("2");
        }
        DeptInfoVo dept = this.tbBaseAdaptRemoteService.getOrgByOrgcode(xf.getSsbmdm());
        if (ObjectUtils.isNotEmpty(dept)) {
            xf.setSsbm(dept.getDeptname());
            xf.setSsbmid(dept.getDeptid());
            xf.setSsbmdm(dept.getDeptcode());
            xf.setSsxgajdm(dept.getFxjcode());
            xf.setSsxgajid(dept.getFxjid());
            xf.setSsxgaj(dept.getFxjname());
            xf.setSssgaj(dept.getDszname());
            xf.setSssgajdm(dept.getDszcode());
            xf.setSssgajid(dept.getDszid());
        }
        return this.baseMapper.updateById(xf);
    }

    @Override
    public Boolean deleteById(String id) {
        int total = this.baseMapper.deleteById(id);
        return total > 0;
    }

    @Override
    public Boolean deleteByIds(List<String> id) {
        if (!CollectionUtils.isEmpty(id)) {
            int total = this.baseMapper.deleteBatchIds(id);
            return total > 0;
        }
        return false;
    }
}
