package com.mosty.base.manager.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.mosty.base.manager.mapper.TbJcglXfMapper;
import com.mosty.base.manager.mapper.TbJcglXfZgMapper;
import com.mosty.base.manager.remote.TbBaseAdaptRemoteService;
import com.mosty.base.manager.service.TbJcglXfService;
import com.mosty.base.manager.service.TbJcglXfZgService;
import com.mosty.base.model.entity.jcgl.TbJcglXf;
import com.mosty.base.model.entity.jcgl.TbJcglXfRw;
import com.mosty.base.model.entity.jcgl.TbJcglXfZg;
import com.mosty.base.model.query.jcgl.TbJcglXfQuery;
import com.mosty.base.model.query.jcgl.TbJcglXfZgQuery;
import com.mosty.base.model.vo.base.DeptInfoVo;
import com.mosty.base.utils.UUIDGenerator;
import com.mosty.common.token.UserInfo;
import com.mosty.common.token.UserInfoManager;
import lombok.AllArgsConstructor;
import org.apache.commons.lang3.ObjectUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.List;

@AllArgsConstructor
@Service
public class TbJcglXfZgServiceImpl extends ServiceImpl<TbJcglXfZgMapper, TbJcglXfZg>
        implements TbJcglXfZgService {

    private final TbBaseAdaptRemoteService tbBaseAdaptRemoteService;

    @Override
    public TbJcglXfZg queryById(String id) {
        return this.baseMapper.selectById(id);
    }

    @Override
    public IPage<TbJcglXfZg> paginQuery(TbJcglXfZgQuery query) {
        query.setSsbmdm(this.tbBaseAdaptRemoteService.getSsbm(query.getSsbmdm(), null));
        Page<TbJcglXfZg> tbJcglXfPage = this.baseMapper.selectPage(new Page<>(query.getPageCurrent(), query.getPageSize()), new LambdaQueryWrapper<TbJcglXfZg>()
                .likeRight(StringUtils.isNotBlank(query.getSsbmdm()), TbJcglXfZg::getSsbmdm, query.getSsbmdm())
                .eq(StringUtils.isNotBlank(query.getSblx()), TbJcglXfZg::getSblx, query.getSblx())
                .like(StringUtils.isNotBlank(query.getSbzt()), TbJcglXfZg::getSbzt, query.getSbzt())
                .ge(StringUtils.isNotBlank(query.getKssj()), TbJcglXfZg::getSbsj, query.getKssj())
                .le(StringUtils.isNotBlank(query.getJssj()), TbJcglXfZg::getSbsj, query.getJssj())
                .orderByDesc(TbJcglXfZg::getXtCjsj)
        );
        return tbJcglXfPage;
    }

    @Override
    public Integer insert(TbJcglXfZg xf) {
        if (StringUtils.isEmpty(xf.getSsbmdm())) {
            UserInfo userInfo = UserInfoManager.get();
            xf.setSsbmdm(userInfo.getDeptCode());
        }
        DeptInfoVo dept = this.tbBaseAdaptRemoteService.getOrgByOrgcode(xf.getSsbmdm());
        if (ObjectUtils.isNotEmpty(dept)) {
            xf.setSsbm(dept.getDeptname());
            xf.setSsbmid(dept.getDeptid());
            xf.setSsbmdm(dept.getDeptcode());
            xf.setSsxgajdm(dept.getFxjcode());
            xf.setSsxgajid(dept.getFxjid());
            xf.setSsxgaj(dept.getFxjname());
            xf.setSssgaj(dept.getDszname());
            xf.setSssgajdm(dept.getDszcode());
            xf.setSssgajid(dept.getDszid());
        }
        xf.setId(UUIDGenerator.getUUID());
        return this.baseMapper.insert(xf);
    }

    @Override
    public Integer update(TbJcglXfZg xf) {
        if (StringUtils.isEmpty(xf.getSsbmdm())) {
            UserInfo userInfo = UserInfoManager.get();
            xf.setSsbmdm(userInfo.getDeptCode());
        }
        DeptInfoVo dept = this.tbBaseAdaptRemoteService.getOrgByOrgcode(xf.getSsbmdm());
        if (ObjectUtils.isNotEmpty(dept)) {
            xf.setSsbm(dept.getDeptname());
            xf.setSsbmid(dept.getDeptid());
            xf.setSsbmdm(dept.getDeptcode());
            xf.setSsxgajdm(dept.getFxjcode());
            xf.setSsxgajid(dept.getFxjid());
            xf.setSsxgaj(dept.getFxjname());
            xf.setSssgaj(dept.getDszname());
            xf.setSssgajdm(dept.getDszcode());
            xf.setSssgajid(dept.getDszid());
        }
        return this.baseMapper.updateById(xf);
    }

    @Override
    public Boolean deleteById(String id) {
        int total = this.baseMapper.deleteById(id);
        return total > 0;
    }

    @Override
    public Boolean deleteByIds(List<String> id) {
        if (!CollectionUtils.isEmpty(id)) {
            int total = this.baseMapper.deleteBatchIds(id);
            return total > 0;
        }
        return false;
    }
}
